@@ -28,7 +28,7 @@ import java.util.*;
  * Created: Sun Nov  4 08:52:45 2001
  *
  * @author Eric D. Friedman
- * @version $Id: THashMap.java,v 1.26 2007/06/29 20:03:10 robeden Exp $
+ * @version $Id: THashMap.java,v 1.28 2008/04/04 18:51:04 robeden Exp $
  */
 public class THashMap<K,V> extends TObjectHash<K> implements Map<K,V>, Externalizable {
     static final long serialVersionUID = 1L;
@@ -202,14 +202,17 @@ public class THashMap<K,V> extends TObjectHash<K> implements Map<K,V>, Externali
     public String toString() {
         final StringBuffer buf = new StringBuffer("{");
         forEachEntry(new TObjectObjectProcedure() {
-                public boolean execute(Object key, Object value) {
-                    buf.append(key);
-                    buf.append("=");
-                    buf.append(value);
-                    buf.append(", ");
-                    return true;
-                }
-            });
+            private boolean first = true;
+            public boolean execute(Object key, Object value) {
+                if ( first ) first = false;
+                else buf.append( "," );
+
+                buf.append(key);
+                buf.append("=");
+                buf.append(value);
+                return true;
+            }
+        });
         buf.append("}");
         return buf.toString();
     }
@@ -389,13 +392,9 @@ public class THashMap<K,V> extends TObjectHash<K> implements Map<K,V>, Externali
         if (size() == 0) return; // optimization
 
         super.clear();
-        Object[] keys = _set;
-        V[] vals = _values;
-
-        for (int i = keys.length; i-- > 0;) {
-            keys[i] = FREE;
-            vals[i] = null;
-        }
+        
+        Arrays.fill(_set, 0, _set.length, FREE);
+        Arrays.fill(_values, 0, _values.length, null);
     }
 
     /**
