@@ -32,7 +32,7 @@ import java.lang.reflect.Array;
  * Created: Sat Nov  3 10:38:17 2001
  *
  * @author Eric D. Friedman
- * @version $Id: THashSet.java,v 1.16 2007/01/10 21:47:00 robeden Exp $
+ * @version $Id: THashSet.java,v 1.19 2008/04/04 18:51:04 robeden Exp $
  */
 
 public class THashSet<E> extends TObjectHash<E>
@@ -180,7 +180,7 @@ public class THashSet<E> extends TObjectHash<E>
     }
 
     /**
-     * Expands the set to accomodate new values.
+     * Expands the set to accommodate new values.
      *
      * @param newCapacity an <code>int</code> value
      */
@@ -247,11 +247,8 @@ public class THashSet<E> extends TObjectHash<E>
      */
     public void clear() {
         super.clear();
-        Object[] set = _set;
 
-        for (int i = set.length; i-- > 0;) {
-            set[i] = FREE;
-        }
+        Arrays.fill(_set, 0, _set.length, FREE);
     }
 
     /**
@@ -357,6 +354,23 @@ public class THashSet<E> extends TObjectHash<E>
         return changed;
     }
 
+    public String toString() {
+        final StringBuffer buf = new StringBuffer("{");
+        forEach(new TObjectProcedure() {
+            private boolean first = true;
+
+            public boolean execute(Object value) {
+                if ( first ) first = false;
+                else buf.append( "," );
+
+                buf.append(value);
+                return true;
+            }
+        });
+        buf.append("}");
+        return buf.toString();
+    }
+
 
     public void writeExternal( ObjectOutput out ) throws IOException {
         // VERSION
