@@ -51,7 +51,7 @@ import java.util.NoSuchElementException;
  * </p>
  *
  * @author Eric D. Friedman
- * @version $Id: TLinkedList.java,v 1.10 2007/06/29 21:42:20 robeden Exp $
+ * @version $Id: TLinkedList.java,v 1.12 2007/11/01 16:08:14 robeden Exp $
  * @see gnu.trove.TLinkable
  */
 
@@ -103,7 +103,7 @@ public class TLinkedList<T extends TLinkable> extends AbstractSequentialList<T>
 
     /**
      * Inserts <tt>linkable</tt> at index <tt>index</tt> in the list.
-     * All values > index are shifted over one position to accomodate
+     * All values > index are shifted over one position to accommodate
      * the new addition.
      *
      * @param index an <code>int</code> value
@@ -229,10 +229,6 @@ public class TLinkedList<T extends TLinkable> extends AbstractSequentialList<T>
      */
     @Override
     public T get(int index) {
-        // Short circuit for easy cases
-        if (index == 0) return _head;
-        if (index == _size - 1) return _tail;
-
         // Blow out for bogus values
         if (index < 0 || index >= _size ) {
             throw new IndexOutOfBoundsException("Index: " + index + ", Size: " + _size);
