@@ -31,7 +31,7 @@ import java.util.*;
  * Created: Sat Nov  3 10:31:38 2001
  *
  * @author Eric D. Friedman
- * @version $Id: THashMapTest.java,v 1.10 2007/03/30 20:53:22 robeden Exp $
+ * @version $Id: THashMapTest.java,v 1.11 2008/04/04 16:31:12 robeden Exp $
  */
 
 public class THashMapTest extends TestCase {
@@ -735,6 +735,18 @@ public class THashMapTest extends TestCase {
     }
 
 
+    public void testToString() {
+        Map<String,String> map = new THashMap<String,String>();
+        map.put( "One", "1" );
+        map.put( "Two", "2" );
+
+        String to_string = map.toString();
+        assertTrue( to_string,
+            to_string.equals( "{One=1,Two=2}" ) ||
+            to_string.equals( "{Two=2,One=1}" ) );
+    }
+
+
     private static class BadHashInteger {
         private final int value;
 
